CircleArea class
A circular area on the map used to restrict the pickable region.
Extends Circle from google_maps_flutter and auto-generates a unique
CircleId so that multiple instances can be used simultaneously.
Constructors
- CircleArea({required LatLng center, required double radius, Color? fillColor, Color? strokeColor, int strokeWidth = 2})
-
Creates a CircleArea centred at
centerwith the givenradiusin metres.
Properties
- center → LatLng
-
Geographical location of the circle center.
finalinherited
- circleId → CircleId
-
Uniquely identifies a
Circle.finalinherited - consumeTapEvents → bool
-
True if the
Circleconsumes tap events.finalinherited - fillColor → Color
-
Fill color in ARGB format, the same format used by Color. The default value is transparent (0x00000000).
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapsId → CircleId
-
A identifier for this object.
no setterinherited
- onTap → VoidCallback?
-
Callbacks to receive tap events for circle placed on this map.
finalinherited
- radius → double
-
Radius of the circle in meters; must be positive. The default value is 0.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeColor → Color
-
Fill color in ARGB format, the same format used by Color. The default value is black (0xff000000).
finalinherited
- strokeWidth → int
-
The width of the circle's outline in screen points.
finalinherited
- visible → bool
-
True if the circle is visible.
finalinherited
- zIndex → int
-
The z-index of the circle, used to determine relative drawing order of
map overlays.
finalinherited
Methods
-
clone(
) → Circle -
Creates a new
Circleobject whose values are the same as this instance.inherited -
copyWith(
{bool? consumeTapEventsParam, Color? fillColorParam, LatLng? centerParam, double? radiusParam, Color? strokeColorParam, int? strokeWidthParam, bool? visibleParam, int? zIndexParam, VoidCallback? onTapParam}) → Circle -
Creates a new
Circleobject whose values are the same as this instance, unless overwritten by the specified parameters.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
Converts this object to something serializable in JSON.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited