maps_place_picker library

Classes

AddressComponent
A component of a formatted address, as returned by the Places / Geocoding APIs.
Bounds
A bounding box defined by a north-east and south-west corner.
CircleArea
Component
A filter component that can be passed to PlacePicker.autocompleteComponents to restrict or bias autocomplete results.
FloatingCard
Geometry
Location geometry as returned by the Places / Geocoding APIs.
Location
Geographic coordinates returned by the Places and Geocoding APIs.
OpeningHoursDetail
Opening hours information for a place.
OpeningHoursPeriod
Opening hours period for a single day.
OpeningHoursPoint
A day-of-week and time-of-day point in an opening hours period.
Photo
Photo associated with a place.
PickResult
The result returned when the user picks a location in PlacePicker.
PlaceDetails
Detailed information about a place as returned by the Places API (New).
PlacePicker
Review
A user-contributed review of a place.
RoundedFrame

Enums

PinState
PriceLevel
Price level of a place, as returned by the Places API (New).
SearchingState

Functions

parsePriceLevel(String? value) PriceLevel
Parses the Places API (New) string price level into a PriceLevel.

Typedefs

IntroModalWidgetBuilder = Widget Function(BuildContext context, Function? close)